@@ -1,4 +1,4 @@
-# Copyright 2020 S. Pawar, S. Semper
+# Copyright 2020 EMS Group TU Ilmenau
 #     https://www.tu-ilmenau.de/it-ems/
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
@@ -18,29 +18,6 @@ r"""
 The Backend
 -----------
 
-Computation Backend
-^^^^^^^^^^^^^^^^^^^
-
-If you have an NVIDIA GPU you might install Cuda and cupy in order to do all
-the heavy calculations on the GPU. The package parses the EADF_BACKEND
-environment variable for the values "cupy" or "numpy" and then tries to import
-cupy. If that succeeds, you are good to go.
-
-However the pattern interpolation functions
-return cupy.ndarrays, which must be converted to a numpy.ndarray. To this end
-we provide the function :py:obj:`.asNumpy`:
-
->>> aGPU = array.pattern(...)
->>> # now convert to numpy
->>> aCPU = eadf.asNumpy(aGPU)
-
-As a developer contributing to the EADF package you can simply import
-
->>> from .backend import xp
-
-and then use xp to call array calculation functions as long as they are both
-covered by cupy and numpy.
-
 Memory Management
 ^^^^^^^^^^^^^^^^^
 
@@ -64,37 +41,23 @@ Environment Variables
 
 A list of all available shell environment variables.
 
- - EADF_BACKEND: numpy or cupy?
  - EADF_LOWMEM: yay or nay?
- - EADF_DTYPE: float or double?
+ - EADF_DTYPE: single or double?
 """
 
 import logging
 import numpy as np
 import os
 
-_BACKEND = os.environ.get("EADF_BACKEND", "numpy")
+__all__ = [
+    "dtype",
+    "rDtype",
+    "cDtype",
+]
+
 _LOWMEM = os.environ.get("EADF_LOWMEM", 0)
 _DTYPE = os.environ.get("EADF_DTYPE", "double")
 
-einsumArgs = {"optimize": "optimal"}
-asNumpy = np.array
-xp = np
-
-if _BACKEND == "cupy":
-    try:
-        import cupy as xp
-
-        asNumpy = xp.asnumpy
-        einsumArgs = {}
-    except ImportError:
-        logging.warning("cupy not importable. using numpy.")
-
-elif _BACKEND == "numpy":
-    pass
-else:
-    logging.warning("unknown backend. using numpy.")
-
 if _LOWMEM:
     lowMemory = True
 else:
@@ -102,8 +65,14 @@ else:
 
 if _DTYPE == "double":
     dtype = "double"
-elif _DTYPE == "float":
-    dtype = "float"
+    rDtype = np.float64
+    cDtype = np.complex128
+elif _DTYPE == "single":
+    dtype = "single"
+    rDtype = np.float32
+    cDtype = np.complex64
 else:
     dtype = "double"
+    rDtype = np.float64
+    cDtype = np.complex128
     logging.warning("Datatype not implemented. using double.")
