@@ -1,4 +1,4 @@
-# Copyright 2020 S. Pawar, S. Semper, C. Wagner
+# Copyright 2020 EMS Group TU Ilmenau
 #     https://www.tu-ilmenau.de/it-ems/
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
@@ -45,18 +45,27 @@ the respective importer methods for further details.
 """
 
 import numpy as np
-from .core import ureg
-from .eadf import EADF
-from .preprocess import interpolateDataSphere
-from .auxiliary import sampleAngles
-from .auxiliary import toGrid
 import scipy.io
 import os.path
-
 from warnings import warn
 from itertools import product
 import pandas as pd
 
+from .core import ureg
+from .eadf import EADF
+from .sphericalharm import interpolateDataSphere
+from .auxiliary import sampleAngles
+from .auxiliary import toGrid
+from .backend import rDtype
+
+__all__ = [
+    "fromAngleListData",
+    "fromWidebandAngData",
+    "fromNarrowBandAngData",
+    "fromArraydefData",
+    "fromHFSS",
+]
+
 
 def fromAngleListData(
     arrCoEleData: np.ndarray,
@@ -258,9 +267,14 @@ def fromWidebandAngData(path: str, **kwargs) -> EADF:
         raise KeyError("fromWidebandAngData: key 'pattern' does not exist.")
 
     arrCoEle = (
-        np.radians(data["pattern"][0][0][0][0][0][1].flatten()) + np.pi / 2
+        np.radians(data["pattern"][0][0][0][0][0][1].flatten().astype(rDtype))
+        + np.pi / 2
     )
-    arrAzi = np.radians(data["pattern"][0][0][0][0][1][1].flatten())
+    arrCoEle = np.linspace(arrCoEle[0], arrCoEle[-1], arrCoEle.shape[0])
+    arrAzi = np.radians(
+        data["pattern"][0][0][0][0][1][1].flatten().astype(rDtype)
+    )
+    arrAzi = np.linspace(arrAzi[0], arrAzi[-1], arrAzi.shape[0])
     arrFreq = data["pattern"][0][0][0][0][4][1]
     arrPattern = data["pattern"][0][0][1]
     # bring the data in the EADF data format
@@ -269,9 +283,9 @@ def fromWidebandAngData(path: str, **kwargs) -> EADF:
     arrPorInd = data["pattern"][0][0][0][0][2][1] - 1
     arrPol = data["pattern"][0][0][0][0][3][1]
 
-    arrPorIndUser = kwargs.get("arrPorIndUser", [])
-    arrPolUser = kwargs.get("arrPolUser", ["h", "v"])
-    arrFreqUser = kwargs.get("arrFreqUser", 0)
+    arrPorIndUser = kwargs.get("arrPorInd", [])
+    arrPolUser = kwargs.get("arrPol", ["h", "v"])
+    arrFreqUser = kwargs.get("arrFreq", 0)
 
     if arrPorIndUser in arrPorInd:
         arrPorInd = arrPorIndUser
@@ -291,7 +305,7 @@ def fromWidebandAngData(path: str, **kwargs) -> EADF:
 
     arrPatternEffective = arrPattern[:, :, arrFreqInd, :, :][
         :, :, :, arrPolInd, :
-    ][:, :, :, :, arrPorInd]
+    ][:, :, :, :, arrPorInd][..., 0]
 
     return EADF(arrPatternEffective, arrCoEle, arrAzi, arrFreq, arrPos)
 
@@ -350,7 +364,7 @@ def fromNarrowBandAngData(path: str, **kwargs) -> EADF:
     )
 
     arrAzi = np.radians(data["pattern"][0][0][1][0][1][1].flatten())
-    arrPorInd = data["pattern"][0][0][1][0][2][1] - 1
+    arrPorInd = data["pattern"][0][0][1][0][2][1]
     arrPol = data["pattern"][0][0][1][0][3][1]
     arrPattern = data["pattern"][0][0][0]
 
@@ -384,6 +398,9 @@ def fromNarrowBandAngData(path: str, **kwargs) -> EADF:
         :, :, :, :, arrPorInd
     ]
 
+    if arrPatternEffective.ndim > 5:
+        arrPatternEffective = arrPatternEffective[:, :, :, :, :, 0]
+
     return EADF(arrPatternEffective, arrCoEle, arrAzi, numFreq, arrPos)
 
 
@@ -426,13 +443,13 @@ def fromArraydefData(path: str) -> EADF:
 
     # matrix for correct addition of the different blocks
     M = (
-        np.matrix(
+        np.array(
             [[1, 1, 1, 1], [1, 1, -1, -1], [1, -1, 1, -1], [1, -1, -1, 1]]
         )
         / 4
     )
     # matrix for correct addition of the different center vectors
-    m = np.matrix([[1, 1], [1, -1]]) / 2
+    m = np.array([[1, 1], [1, -1]]) / 2
 
     GkT = np.empty((numEle // 2, numAzi // 2, 4), dtype=np.complex128)
     G = np.empty(
@@ -525,7 +542,7 @@ def fromArraydefData(path: str) -> EADF:
                     [BT[:, :, 0], B_phi_0[:, [0]], np.fliplr(BT[:, :, 1])],
                     [
                         B_theta_0[[0], :],
-                        np.matrix(Gk2[-1, -1]),
+                        np.array(Gk2[-1, -1]),
                         np.fliplr(B_theta_0[[1], :]),
                     ],
                     [
@@ -559,7 +576,10 @@ def fromArraydefData(path: str) -> EADF:
     # create angle vectors and so on
     arrCoEle = np.linspace(0, np.pi, numEle // 2 + 1)
     arrFreq = np.ones(1)
-    arrPos = data["arraydef"].PosData.T
+    if hasattr(data["arraydef"], "posData"):
+        arrPos = data["arraydef"].PosData.T
+    else:
+        arrPos = np.ones((3, numPort))
 
     return EADF(BP, arrCoEle, arrAzi, arrFreq, arrPos)
 
